@@ -64,6 +64,10 @@ struct c_block *cb_ptr;
     cb_ptr -> interpolator   = ITERATE;
     cb_ptr -> station_delay.ref  = 150e-9;   // a priori station delay of 150 ns
     cb_ptr -> station_delay.rem  = 150e-9;
+    cb_ptr -> pc_delay_l.ref = 0.0;
+    cb_ptr -> pc_delay_l.rem = 0.0;
+    cb_ptr -> pc_delay_r.ref = 0.0;
+    cb_ptr -> pc_delay_r.rem = 0.0;
 
                                                                       // vectors
     for (i=0; i<6; i++)
