@@ -27,12 +27,12 @@ struct type_pass *pass;
     complex wght_phsr;
     int maxchan[MAXFREQ], i, j, np, fr, ap, lag, st, seg, lagbit;
     double ap_seg, c_mag(), c_phase(), max[MAXFREQ], maxv, peak, frac,
-                        sbdbox[MAXFREQ], rj, c, ap_cnt[MAXAP], nap;
-    double offset, maxamp, sumwt, q[3];
-    double temp[MAXAP];
-    double yy[3];
-    int n, ij;
-    int maxi, npmax, nl;
+                        sbdbox[MAXFREQ], rj, c, ap_cnt[MAXAP], nap,
+           offset, maxamp, sumwt, q[3],
+           temp[MAXAP],
+           yy[3], eff_npol;
+    int n, ij,
+        maxi, npmax, nl;
                                         /* Make sure data will fit */
     if (param.nlags*param.num_ap > MAX_APXLAG)
         {
@@ -231,12 +231,11 @@ struct type_pass *pass;
        status.sbdbox[fr] = maxchan[fr] + peak + 1;
        }
     status.sbdbox[MAXFREQ] = nl + 1 + status.sbd_max / status.sbd_sep;
-
-                                        /*  Fill in phase cal - done elsewhere */
-
+                                        // effective number of polarizations
+    eff_npol = pass->npols > 2 ? 2 : pass->npols;
                                         /*  Signal to Noise Ratio */
     status.snr = status.delres_max * param.inv_sigma 
-            * sqrt((double)status.total_ap_frac * pass->npols)
+            * sqrt((double)status.total_ap_frac * eff_npol)
                        / (1.0E4 * status.amp_corr_fact);
     msg ("SNR %le", 0, status.snr);
 
@@ -285,12 +284,8 @@ struct type_pass *pass;
                     plot.weights[fr][ap] /= 2.0;
 
                 Z = c_mult (datum->sbdelay[status.max_delchan],
-                                vrot(ap, status.dr_max_global, 
-                                        status.mbd_max_global, fr, 
-                                        //datum->sband, pass));
-                                        0, pass));
-                                        // rescale for possible multiple pols added together
-                plot.phasor[fr][ap] = s_mult (Z, 1.0/pass->npols);
+                      vrot(ap, status.dr_max_global, status.mbd_max_global, fr, 0, pass));
+                plot.phasor[fr][ap] = Z;
                 }
             else
                 plot.phasor[fr][ap] = c_zero();
