@@ -35,6 +35,11 @@
 #endif /* P_tmpdir */
 
 #define pi 3.141592654
+                                        // polararization bit masks
+#define LREF 1
+#define RREF 2
+#define LREM 4
+#define RREM 8
                                         /* Set up some convenient macros */
                                         /* for inserting justified text using */         
                                         /* native postscript fonts */
@@ -126,6 +131,7 @@ struct type_221 **t221)
     int totpts, wrap, len, first, nb, fd, size, filesize;
     int nlsb, nusb, izero, numsb, srate;
     int pcaref, pcarem;
+    int eff_npols, polars;
     FILE *fp, *gs, *popfil;
     char *pplot, *showpage, *end, trailer[1024];
     char absexec[256], which_command[256];
@@ -444,7 +450,7 @@ struct type_221 **t221)
             cpgdraw (plot_time, 1.0);
             }
                                         /* Switch to segment/amplitude space */
-        ymax = status.delres_max * 2.0;
+        ymax = status.delres_max * 3.0;
         if (ymax == 0.0)
             {
             msg ("overriding ymax of 0 in channel plot; data suspect", 2);
@@ -914,33 +920,59 @@ struct type_221 **t221)
     sprintf (buf, "%s, %s, %s", rootname, root->scan_name, param.baseline);
     psright (1.0, 0.98, buf);
                                         /* Convert to pol. string */
+    polars = 0;
     if (param.pol == 0)
         {
         if (pass->pol == POL_LL) 
+            {
             sprintf (polstr, "LL");
+            polars |= LREF | LREM;
+            }
         else if (pass->pol == POL_RR)
+            {
             sprintf (polstr, "RR");
+            polars |= RREF | RREM;
+            }
         else if (pass->pol == POL_LR) 
+            {
             sprintf (polstr, "LR");
+            polars |= LREF | RREM;
+            }
         else if (pass->pol == POL_RL) 
+            {
             sprintf (polstr, "RL");
+            polars |= RREF | LREM;
+            }
         }
     else if (param.pol < 16)
         {
         polstr[0] = '\0';
         if (param.pol & POLMASK_LL)
+            {
             strcat (polstr, "+LL");
+            polars |= LREF | LREM;
+            }
         if (param.pol & POLMASK_RR)
+            {
             strcat (polstr, "+RR");
+            polars |= RREF | RREM;
+            }
         if (param.pol & POLMASK_LR)
+            {
             strcat (polstr, "+LR");
+            polars |= LREF | RREM;
+            }
         if (param.pol & POLMASK_RL)
+            {
             strcat (polstr, "+RL");
+            polars |= RREF | LREM;
+            }
         strcpy (polstr, polstr+1);      // chop off leading '+'
         }
     else
         {
         sprintf (polstr, "Ixy");
+        polars |= LREF | LREM | RREF | RREM;
         }
     sprintf (buf, "%.8s - %.8s, fgroup %c, pol %s", fringe.t202->ref_name,
                     fringe.t202->rem_name, pass->pass_data[0].fgroup, polstr);
@@ -1190,30 +1222,86 @@ struct type_221 **t221)
             }
         ypos -= spacing;
 
-        sprintf (buf, "%d",                   // reference pcal frequencies
-            (param.pc_mode[0] == MULTITONE) ? // source of pcal freqs dep. on mode
-                (int) (500 * bandwidth) :     // midband in KHz
+        if (param.pc_mode[0] != MULTITONE)    // don't print mt freq (at center)
+            {
+            sprintf (buf, "%d",               // reference pcal frequencies
                 (int)pass->pass_data[i].pc_freqs[0][pass->pci[0][i]]/1000);
-        psleft (xpos, ypos, buf);
-        if (i == start_plot) 
-            {
-            psleft (labelpos, ypos, "PC freqs");
-            sprintf (buf, "%c", param.baseline[0]);
-            psright (0.04, ypos, buf);
+            psleft (xpos, ypos, buf);
+            if (i == start_plot) 
+                {
+                psleft (labelpos, ypos, "PC freqs");
+                sprintf (buf, "%c", param.baseline[0]);
+                psright (0.04, ypos, buf);
+                }
+            ypos -= spacing;
             }
-        ypos -= spacing;
 
-        sprintf (buf, "%d",                   // remote pcal frequencies
-            (param.pc_mode[1] == MULTITONE) ? // source of pcal freqs dep. on mode
-                (int) (500 * bandwidth) :     // midband in KHz
-                (int)pass->pass_data[i].pc_freqs[1][pass->pci[1][i]]/1000);
-        psleft (xpos, ypos, buf);
-        if (i == start_plot) 
+        if (param.pc_mode[1] != MULTITONE)    // don't print mt freq (at center)
             {
-            sprintf (buf, "%c", param.baseline[1]);
-            psright (0.04, ypos, buf);
+            sprintf (buf, "%d",               // remote pcal frequencies
+                (int)pass->pass_data[i].pc_freqs[1][pass->pci[1][i]]/1000);
+            psleft (xpos, ypos, buf);
+            if (i == start_plot) 
+                {
+                psleft (labelpos, ypos, "PC freqs");
+                sprintf (buf, "%c", param.baseline[1]);
+                psright (0.04, ypos, buf);
+                }
+            ypos -= spacing;
             }
-        ypos -= spacing;
+                                        // reference mt delays by channel
+        if (param.pc_mode[0] == MULTITONE && polars & LREF)
+            {
+            sprintf (buf, "%.1f", 1e9 * status.pc_delay[i][0][0]);
+            psleft (xpos, ypos, buf);
+            if (i == start_plot) 
+                {
+                psleft (labelpos, ypos, "PC L/X/H delays (ns)");
+                sprintf (buf, "%c", param.baseline[0]);
+                psright (0.04, ypos, buf);
+                }
+            ypos -= spacing;
+            }
+
+        if (param.pc_mode[1] == MULTITONE && polars & LREM) 
+            {
+            sprintf (buf, "%.1f", 1e9 * status.pc_delay[i][1][0]);
+            psleft (xpos, ypos, buf);
+            if (i == start_plot) 
+                {
+                psleft (labelpos, ypos, "PC L/X/H delays (ns)");
+                sprintf (buf, "%c", param.baseline[1]);
+                psright (0.04, ypos, buf);
+                }
+            ypos -= spacing;
+            }
+
+        if (param.pc_mode[0] == MULTITONE && polars & RREF)
+            {
+            sprintf (buf, "%.1f", 1e9 * status.pc_delay[i][0][1]);
+            psleft (xpos, ypos, buf);
+            if (i == start_plot) 
+                {
+                psleft (labelpos, ypos, "PC R/Y/V delays (ns)");
+                sprintf (buf, "%c", param.baseline[0]);
+                psright (0.04, ypos, buf);
+                }
+            ypos -= spacing;
+            }
+
+        if (param.pc_mode[1] == MULTITONE && polars & RREM)
+            {
+            sprintf (buf, "%.1f", 1e9 * status.pc_delay[i][1][1]);
+            psleft (xpos, ypos, buf);
+            if (i == start_plot) 
+                {
+                psleft (labelpos, ypos, "PC R/Y/V delays (ns)");
+                sprintf (buf, "%c", param.baseline[1]);
+                psright (0.04, ypos, buf);
+                }
+            ypos -= spacing;
+            }
+
         sprintf (buf, "%d:%d", (int)rint((double)fringe.t207->ref_pcphase[i].lsb),
                                (int)rint((double)fringe.t207->rem_pcphase[i].lsb));
         psleft (xpos, ypos, buf);
@@ -1271,15 +1359,6 @@ struct type_221 **t221)
             psright (0.04, ypos, buf);
             }
         ypos -= spacing;
-/*         sprintf (buf, "00:00"); */
-/*         psleft (xpos, ypos, buf); */
-/*         if (i == 0)  */
-/*             { */
-/*             psleft (labelpos, ypos, "PC rms"); */
-/*             sprintf (buf, "%c:%c", param.baseline[0], param.baseline[1]); */
-/*             psright (0.04, ypos, buf); */
-/*             } */
-/*         ypos -= spacing; */
                                         /* Channel ids, reference station */
         if (polstr[0] == 'L')
             sprintf (buf, "%s %s", pass->pass_data[i].ch_usb_lcp[0],
@@ -1569,8 +1648,9 @@ struct type_221 **t221)
     psleft (0.23, ypos, "Inc. frq. avg.");
     sprintf (buf, "%.3f", fringe.t208->inc_chan_ampl);
     psleft (0.35, ypos, buf);
-
-    sprintf (buf, "Data rate(Mb/s): %d", numsb * srate * param.bits_sample);
+                                    // effective number of polarizations is max of 2
+    eff_npols = (pass->npols > 2) ? 2 : pass->npols;
+    sprintf (buf, "Data rate(Mb/s): %d", numsb * eff_npols * srate * param.bits_sample);
     psleft (0.5, ypos, buf);
     sprintf (buf, "nlags: %d", param.nlags);
     psleft (0.65, ypos, buf);
