@@ -50,13 +50,13 @@ norm (struct type_pass *pass,
     unsigned short bitshift;
     double theta, shift, dd, norm_const, fb_fact, fb_amp_ratio();
     double samp_per_ap, corrfact, rawcorr, factor, mean;
-    double diff_delay, deltaf, polcof;
-    int flagmask,
-        freq_no,
+    double diff_delay, deltaf, polcof, polcof_sum;
+    int freq_no,
         ibegin,
         sindex,
         pol,
-        npolpasses;
+        usb_present, lsb_present;
+
     int stnpol[2][4] = {0, 1, 0, 1, 0, 1, 1, 0}; // [stn][pol] = 0:L/X/H, 1:R/Y/V
     extern struct type_param param;
     extern struct type_status status;
@@ -68,12 +68,6 @@ norm (struct type_pass *pass,
         }
     else                                // linear combination of polarizations
         ips = 0;
-                                        // for special case of Ixy mode we have the
-                                        // power for 2 polarizations, but make 4 passes
-    if (param.pol == POL_IXY)
-        npolpasses = 4;
-    else
-        npolpasses = pass->npols;
         
     nlags = param.nlags;
     samp_per_ap = param.acc_period / param.samp_period;
@@ -91,6 +85,18 @@ norm (struct type_pass *pass,
                                         /* -1.0 means no data, not zero weight */
     datum->usbfrac = -1.0;
     datum->lsbfrac = -1.0;
+
+    polcof_sum = 0.0;
+
+    usb_present = FALSE;
+    lsb_present = FALSE;
+                                        // check sidebands for each pol. for data
+    for (ip=ips; ip<pass->pol+1; ip++)
+        {
+        usb_present |= ((datum->flag & (USB_FLAG << 2*ip)) != 0);
+        lsb_present |= ((datum->flag & (LSB_FLAG << 2*ip)) != 0);
+        }
+    datum->sband = usb_present - lsb_present;
                                         /*  sideband # -->  0=upper , 1= lower */
     for (sb = 0; sb < 2; sb++) 
       {
@@ -99,20 +105,14 @@ norm (struct type_pass *pass,
           xcor[i]=c_zero();
           xp_spec[i] = c_zero();
           }
-
       for (ip=ips; ip<pass->pol+1; ip++) // loop over polarization products
         {
         if (param.pol)
             pol = ip;
-
-        if (sb) 
-            flagmask = LSB_FLAG << 2*pol;
-        else
-            flagmask = USB_FLAG << 2*pol;
-                                        /* If no data, skip over this sideband*/
-        if ((datum->flag & flagmask) == 0)
+                                        // If no data for this sb/pol, go on to next
+        if (sb == 0 & usb_present == 0
+         || sb == 1 & lsb_present == 0)
             continue;
-                                        /* Convenience pointer */
                                         /* Pluck out the requested polarization */
         switch (pol)
             {
@@ -137,16 +137,7 @@ norm (struct type_pass *pass,
                              1.0;
                          break;
             }
-                                        // Keep cumulative track of sideband info
-                                        // once per polarizaton
-        if (ip == pass->pol)
-            {
-            if (sb) 
-                datum->sband -= 1;      // LSB
-            else    
-                datum->sband += 1;      // USB
-            }
-            
+        polcof_sum += polcof;
         if (param.corr_type == MK4HDW)
             {
                                         /* Calculate normalization quantities */
@@ -250,9 +241,9 @@ norm (struct type_pass *pass,
                     || (z.im > param.cor_limit) || (z.im < -param.cor_limit)) 
                     {
                     status.large_errors++;
-                                        /* mark this sideband & pol piece of this AP bad */
+                                        // mark this sideband & pol piece of this AP bad
                     datum->flag &= ~(1 << (2 * pol + sb));
-                    break;                  /* break out of loop over lags  */
+                    break;              // break out of loop over lags
                     }
                                         // apply pcal to data and add into xcor
                                         // iff this is a requested pol product
@@ -275,14 +266,14 @@ norm (struct type_pass *pass,
                         if (datum->lsbfrac < 0.0) 
                             datum->lsbfrac = 0.0;
                         datum->lsbfrac += (double) (cosbits)
-                                        / (samp_per_ap * nlags * npolpasses);
+                                        / (samp_per_ap * nlags);
                         }
                     else 
                         {
                         if (datum->usbfrac < 0.0) 
                             datum->usbfrac = 0.0;
                         datum->usbfrac += (double) (cosbits)
-                                        / (samp_per_ap * nlags * npolpasses);
+                                        / (samp_per_ap * nlags);
                         }
                     }
                 }                       /* end of loop over i (lags) */
@@ -385,26 +376,35 @@ norm (struct type_pass *pass,
                 if (sb) 
                     {
                     datum->lsbfrac = 1.0;
-                    status.ap_frac[sb][fr] += datum->lsbfrac / npolpasses;
-                    status.total_ap_frac   += datum->lsbfrac / npolpasses;
+                    status.ap_frac[sb][fr] += datum->lsbfrac;
+                    status.total_ap_frac   += datum->lsbfrac;
                     }
                 else 
                     {
                     datum->usbfrac = 1.0;
-                    status.ap_frac[sb][fr] += datum->usbfrac / npolpasses;
-                    status.total_ap_frac   += datum->usbfrac / npolpasses;
+                    status.ap_frac[sb][fr] += datum->usbfrac;
+                    status.total_ap_frac   += datum->usbfrac;
                     }
                 }
             fb_fact = 1.0;          // may want to re-examine this assumption
             theta = 0.0;            // no fractional bit induced error correction
 
+            diff_delay = pass->control.delay_offs[freq_no].rem 
+                       - pass->control.delay_offs[freq_no].ref;
+                                    // add in phase effects if multitone delays 
+                                    // were extracted
+            if (pass->control.nsamplers && param.pc_mode[0] == MULTITONE 
+                                        && param.pc_mode[1] == MULTITONE)      
+                diff_delay += 1e9 * (datum->rem_sdata.mt_delay[stnpol[1][pol]] 
+                                   - datum->ref_sdata.mt_delay[stnpol[0][pol]]);
+            msg ("ap %d fr %d pol %d diff_delay %f", -2, ap, fr, pol, diff_delay);
+                                    // loop over spectral points
             for (i=0; i<nlags; i++)
-                {
                                     // filter out any nan's, if present
                 if (isnan (rawdatum->ld.spec[i].re) || isnan (rawdatum->ld.spec[i].im))
-                    {
-                    msg ("omitting nan's in visibility for ap %d fr %d lag %i", 2, ap, fr, i);
-                    }
+                    msg ("omitting nan's in visibility for ap %d fr %d lag %i", 
+                          2, ap, fr, i);
+                     
                                     // add in iff this is a requested pol product
                 else if (param.pol & 1<<ip || param.pol == 0)
                     {           
@@ -413,40 +413,24 @@ norm (struct type_pass *pass,
                                     // rotate each pol prod by pcal prior to adding in
                     if (sb==0)
                         z = c_mult (z, datum->pc_phasor[ip]);
-                    else                // use conjugate of usb pcal tone for lsb
+                    else            // use conjugate of usb pcal tone for lsb
                         z = c_mult (z, conju (datum->pc_phasor[ip]));
-                                        // scale phasor by polarization coefficient
+                                    // scale phasor by polarization coefficient
                     z = s_mult (z, polcof);
-
                                     // corrections to phase as fn of freq based upon 
                                     // delay calibrations
-                                    // apply delay offset phase ramp
-                                    // iff the offset is non-zero
-                    diff_delay = pass->control.delay_offs[freq_no].rem 
-                               - pass->control.delay_offs[freq_no].ref;
-                                    // add in phase effects if multitone delays 
-                                    // were extracted
-                    if (pass->control.nsamplers && param.pc_mode[0] == MULTITONE 
-                                                && param.pc_mode[1] == MULTITONE)      
-                        diff_delay += 1e9 * (datum->rem_sdata.mt_delay[stnpol[1][pol]] 
-                                           - datum->ref_sdata.mt_delay[stnpol[0][pol]]);
-                                    // apply only non-zero delay effects 
-                    if (diff_delay != 0.0)
-                        {
-                        msg ("ap %d fr %d diff_delay %f", -2, ap, fr, diff_delay);
-                                    // calculate offset frequency of DC edge in
-                                    // GHz from the reference frequency for USB
-                            deltaf = 1e-3 * i / (2e6 * param.samp_period * nlags);
+
+                                    // calculate offset frequency in GHz 
+                                    // from DC edge for this spectral point
+                    deltaf = 1e-3 * i / (2e6 * param.samp_period * nlags);
                                     // refer phase ramp to actual midband
-                            if (datum->sband)
-                                deltaf -= 1e-3 * datum->sband / (4e6 * param.samp_period);
+                    if (datum->sband)
+                        deltaf -= 1e-3 / (4e6 * param.samp_period);
                                     // apply phase ramp to spectral points 
-                            z = c_mult (z, c_exp (-2.0 * M_PI * diff_delay * deltaf));
-                        }
+                    z = c_mult (z, c_exp (-2.0 * M_PI * diff_delay * deltaf));
                     xp_spec[i].re += z.re;
                     xp_spec[i].im += z.im;
                     }
-                }
             }                       // end of spectral mode code
         }                           // bottom of polarization loop
 
@@ -504,51 +488,51 @@ norm (struct type_pass *pass,
     if (datum->lsbfrac >= 0.0)
         factor += datum->lsbfrac;
     if ((datum->usbfrac >= 0.0) && (datum->lsbfrac >= 0.0)) 
-        factor /= 2.0;
+        factor /= 4.0;              // x2 factor for sb and for polcof
+                                    // correct for multiple pols being added in
+    factor *= polcof_sum;
     if (factor > 0.0)
         factor = 1.0 / factor;
-    msg ("usbfrac %1f lsbfrac %1f factor %1f", -2, datum->usbfrac, datum->lsbfrac, factor);
+    msg ("usbfrac %f lsbfrac %f polcof_sum %f factor %1f", -2, 
+            datum->usbfrac, datum->lsbfrac, polcof_sum, factor);
     for (i=0; i<4*nlags; i++) 
         S[i] = s_mult (S[i], factor);
 
+                                    /* Collect the results */
+    if(datum->flag != 0)
+        {
                                     // corrections to phase as fn of freq based upon 
                                     // delay calibrations
                                     // apply delay offset phase ramp
                                     // spectral version is done above
-    if (rawdatum -> type != SPECTRAL)
-        {
-        diff_delay = pass->control.delay_offs[freq_no].rem 
-                   - pass->control.delay_offs[freq_no].ref;
+        if (param.corr_type == MK4HDW)
+            {
+            diff_delay = pass->control.delay_offs[freq_no].rem 
+                       - pass->control.delay_offs[freq_no].ref;
                                     // add in phase effects if multitone delays 
                                     // were extracted
-        if (pass->control.nsamplers && param.pc_mode[0] == MULTITONE 
-                                    && param.pc_mode[1] == MULTITONE)      
-            diff_delay += 1e9 * (datum->rem_sdata.mt_delay[stnpol[1][pol]] 
-                               - datum->ref_sdata.mt_delay[stnpol[0][pol]]);
+            if (pass->control.nsamplers && param.pc_mode[0] == MULTITONE 
+                                        && param.pc_mode[1] == MULTITONE)      
+                diff_delay += 1e9 * (datum->rem_sdata.mt_delay[stnpol[1][pol]] 
+                                   - datum->ref_sdata.mt_delay[stnpol[0][pol]]);
 
-        if (diff_delay != 0.0)      // apply only non-zero delay effects
-            {
-            msg ("ap %d fr %d diff_delay %f", -2, ap, fr, diff_delay);
-            for (i=1, j=4*nlags-1; i<nlags; i++, j--)
+            if (diff_delay != 0.0)  // apply only non-zero delay effects
                 {
+                msg ("ap %d fr %d diff_delay %f", -2, ap, fr, diff_delay);
+                for (i=1, j=4*nlags-1; i<nlags; i++, j--)
+                    {
                                     // calculate offset frequency of DC edge in
                                     // GHz from the reference frequency for USB
-                deltaf = 1e-3 * i / (2e6 * param.samp_period * nlags);
-                if (datum->sband)       // refer phase ramp to actual midband
-                    deltaf -= 1e-3 * datum->sband / (4e6 * param.samp_period);
+                    deltaf = 1e-3 * i / (2e6 * param.samp_period * nlags);
+                    if (datum->sband)       // refer phase ramp to actual midband
+                        deltaf -= 1e-3 * datum->sband / (4e6 * param.samp_period);
                                     // apply phase ramp to spectral points 
-                S[i] = c_mult (S[i], c_exp (-2.0 * M_PI * diff_delay * deltaf));
+                    S[i] = c_mult (S[i], c_exp (-2.0 * M_PI * diff_delay * deltaf));
                                     // ditto for LSB
-                deltaf = 1e-3 * i / (2e6 * param.samp_period * nlags);
-                if (datum->sband)   // refer phase ramp to actual midband
-                    deltaf += 1e-3 * datum->sband / (4e6 * param.samp_period);
-                S[j] = c_mult (S[j], c_exp (2.0 * M_PI * diff_delay * deltaf));
+                    S[j] = c_mult (S[j], c_exp (2.0 * M_PI * diff_delay * deltaf));
+                    }
                 }
             }
-        }
-                                    /* Collect the results */
-    if(datum->flag != 0)
-        {
                                     /* FFT to single-band delay */
         FFT1 (S, nlags*4, 1, xcor, 1);
                                     /* Place SB delay values in data structure */
