@@ -35,7 +35,8 @@ void pcalibrate (struct type_pass *pass,
         nsubs,
         ap_subint_start,
         kap,
-        ipol;                       // 0:1 = L:R or X:Y
+        ipol,                       // 0:1 = L:R or X:Y
+        ndelpts;
 
     double minf,
            peak,
@@ -46,7 +47,12 @@ void pcalibrate (struct type_pass *pass,
            theta_ion,
            delta_phase[2],
            pc_amb,
-           sdelay;
+           sdelay,
+           y[3],
+           q[3],
+           ymax,
+           ampmax,
+           del_avg;
         
     complex pc_avg[2][MAX_PCF],
             pc_adj[2],
@@ -72,7 +78,7 @@ void pcalibrate (struct type_pass *pass,
             s_mult (complex, double),
             c_mean (complex *, int),
             c_exp (double);
-    
+    int parabola (double *, double, double, double *, double *, double *);
  
     fdata = pass->pass_data + fr;
                                     // loop over reference and remote stations
@@ -111,6 +117,8 @@ void pcalibrate (struct type_pass *pass,
           ip = 0;
           nsubs = 0;
           pc_adj[stn] = c_zero ();
+          ndelpts = 0;
+          del_avg = 0.0;
                                     // apply manual or offset pcal phase
           delta_phase[stn] = theta_ion + M_PI * status.pc_offset[fr][stn][ipol] / 180.0;
                                     // loop over time within the scan
@@ -203,9 +211,14 @@ void pcalibrate (struct type_pass *pass,
                         peak = c_mag (delay_fn[i]);
                         indpeak = i;
                         }
+                                    // interpolate to optimal value
+                y[1] = peak;
+                y[0] = c_mag (delay_fn[(indpeak+FFTSIZE-1)%FFTSIZE]);
+                y[2] = c_mag (delay_fn[(indpeak+FFTSIZE+1)%FFTSIZE]);
+                parabola (y, -1.0, 1.0, &ymax, &ampmax, q);
+
                                     // DC is in 0th element
-                delay = indpeak / 256.0 / param.pcal_spacing[stn];       
-                                    // interpolate to optimal value (NYI)
+                delay = (indpeak+ymax) / 256.0 / param.pcal_spacing[stn];       
                                     // find corresponding delay in suitable range
                 pc_amb = 1 / param.pcal_spacing[stn];
                 while (delay < sdelay - pc_amb / 2.0)
@@ -224,7 +237,8 @@ void pcalibrate (struct type_pass *pass,
                         theta = 2.0 * M_PI * delay * deltaf;
 
                         rotval[i] = c_mult (pc_avg[stn][i], c_exp (theta));
-                        msg ("stn %d chan %d pol %d ap %d-%d tone %d rotated pcal phasor %7.2f %7.2f", 0, 
+                        msg ("stn %d chan %d pol %d ap %d-%d tone %d "
+                             "rotated pcal phasor %7.2f %7.2f", 0, 
                              stn, fr, ipol, ap_subint_start, ap, i,
                              1e3 * c_mag(rotval[i]), 180.0 / M_PI * c_phase(rotval[i]));
                         nin++;
@@ -244,6 +258,9 @@ void pcalibrate (struct type_pass *pass,
                                     // also rotate by offsets and ionosphere
                     ksd->mt_pcal[ipol] = c_mult (pc_sub[stn], c_exp(delta_phase[stn]));
                     ksd->mt_delay[ipol] = delay;
+                                    // keep track of avg delay for ch/stn/pol
+                    del_avg += delay;
+                    ndelpts++;
                     }
                                     // maintain a running total
                 pc_adj[stn] = c_add (pc_sub[stn], pc_adj[stn]);
@@ -274,6 +291,8 @@ void pcalibrate (struct type_pass *pass,
                                     // make copies of amplitude and phase
           status.pc_meas[fr][stn][ipol] = c_phase (pc_adj[stn]);
           status.pc_phase[fr][stn][ipol] = status.pc_meas[fr][stn][ipol];
+                                    // store delay average per channel, stn, and pol
+          status.pc_delay[fr][stn][ipol] = del_avg / ndelpts;
                                     // rotate by iono. and offset if not already done
           if (param.pc_mode[stn] != MULTITONE)
               status.pc_phase[fr][stn][ipol] += delta_phase[stn];
