@@ -2,6 +2,7 @@
 // of channels sharing a sampler to have the same, mean value
 //
 // Initial code                                        rjc  2011.10.24
+// do independent averaging for each polarization      rjc  2012.3.23
 
 #include <stdio.h>
 #include <string.h>
@@ -25,9 +26,11 @@ void sampler_delays (struct type_pass *pass)
     {
     int n,
         k,
+        ksum,
         fno,
         ap,
-        stnpol[2][4] = {0, 1, 0, 1, 0, 1, 1, 0}; // [stn][pol] = 0:L/X/H, 1:R/Y/V
+        stnpol[2][4] = {0, 1, 0, 1, 0, 1, 1, 0}, // [stn][pol] = 0:L/X/H, 1:R/Y/V
+        ip;
 
     char *pool;
 
@@ -37,13 +40,14 @@ void sampler_delays (struct type_pass *pass)
     struct freq_corel *fdata;
     struct data_corel *datum;
     extern struct type_param param;
-
+                                    // debug print sampler group
     for (n=0; n<pass->control.nsamplers; n++)
 	    msg ("Sampler group %d: %s", 1, n, pass->control.psamplers[n]);
 
                                     // loop over all ap's
     for (ap = pass->ap_off; ap < pass->ap_off + pass->num_ap; ap++)
-        {
+                                    // loop over both polarizations
+      for (ip=0; ip<2; ip++)
                                     // loop over all of the sampler pools
         for (n=0; n<pass->control.nsamplers; n++)
             {
@@ -51,6 +55,7 @@ void sampler_delays (struct type_pass *pass)
             avg_ref = 0.0;
             avg_rem = 0.0;
                                     // find average delay offset for this pool
+            ksum = 0;
             for (k=0; k<strlen(pool); k++)
                 {
                 fno = sampler_fcode (pass->pass_data, pass->nfreq, pool[k]);
@@ -59,12 +64,16 @@ void sampler_delays (struct type_pass *pass)
                     fdata = pass->pass_data + fno;
                     datum = fdata->data + ap;
 
-                    avg_ref += datum->ref_sdata.mt_delay[stnpol[0][pass->pol]];
-                    avg_rem += datum->rem_sdata.mt_delay[stnpol[1][pass->pol]];
+                    avg_ref += datum->ref_sdata.mt_delay[ip];
+                    avg_rem += datum->rem_sdata.mt_delay[ip];
+                    ksum++;
                     }
                 }
-            avg_ref /= k;
-            avg_rem /= k;
+            if (ksum > 0)
+                {
+                avg_ref /= ksum;
+                avg_rem /= ksum;
+                }
                                     // apply average to all members of pool
             for (k=0; k<strlen(pool); k++)
                 {
@@ -74,10 +83,9 @@ void sampler_delays (struct type_pass *pass)
                     fdata = pass->pass_data + fno;
                     datum = fdata->data + ap;
 
-                    datum->ref_sdata.mt_delay[stnpol[0][pass->pol]] = avg_ref;
-                    datum->rem_sdata.mt_delay[stnpol[1][pass->pol]] = avg_rem;
+                    datum->ref_sdata.mt_delay[ip] = avg_ref;
+                    datum->rem_sdata.mt_delay[ip] = avg_rem;
                     }
                 }
             }
-        }
     }
